#
# spec file for package ghc-tasty
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name tasty
Name:           ghc-%{pkg_name}
Version:        1.1.0.2
Release:        1.2
Summary:        Modern and extensible testing framework
License:        MIT
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-ansi-terminal-devel
BuildRequires:  ghc-async-devel
BuildRequires:  ghc-clock-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-optparse-applicative-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-stm-devel
BuildRequires:  ghc-tagged-devel
BuildRequires:  ghc-unbounded-delays-devel
BuildRequires:  ghc-unix-devel
BuildRequires:  ghc-wcwidth-devel

%description
Tasty is a modern testing framework for Haskell. It lets you combine your unit
tests, golden tests, QuickCheck/SmallCheck properties, and any other types of
tests into a single test suite.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%changelog
* Mon Jul  9 2018 psimons@suse.com
- Update tasty to version 1.1.0.2.
  Changes
  =======
  Version 1.1.0.2
  - --------------
  Fix a bug where some (mostly Asian) characters would break alignment in the
  terminal output
  Version 1.1.0.1
  - --------------
  Fix a bug where `-l` was still using `/` instead of `.` as a field separator
  Version 1.1
  - ----------
  * *NOTE**: This major release contains some breaking changes to the semantics of patterns.
  In the original pattern design I didn't notice the conflict between using `/` as
  a field separator and as the AWK syntax for pattern matching `/.../`.
  The new patterns have been around for a relatively short time (5 months), so
  hopefully the breakage won't be too big. I'm sorry about any problems caused by
  the change.
  See <https://github.com/feuerbach/tasty/issues/220> for the discussion.
  * The field separator in patterns is changed from slash (`/`) to period (`.`),
    and `.` is now allowed in raw patterns.
    The field separator is used to join the group names and the test
    name when comparing to a pattern such as `-p foo` or `-p /foo/`.
    If you used
  - p 'foo/bar'
    or
  - p '/foo\/bar/'
    before, now you should use
  - p 'foo.bar'
    or
  - p '/foo.bar/'
    if you meant "test/group `bar` inside group `foo`, or
  - p '/foo\/bar/'
    if you meant "test/group containing `foo/bar` in the name".
    The need for escaping the slash inside the `/.../` pattern was precisely the
    motivation for this change.
  * Raw patterns (ones that are not AWK expressions) may no longer contain slashes
    (`/`).
    So
  - p 'foo/bar'
    is no longer allowed, and
  - p '/foo/'
    is now parsed as an AWK expression `/foo/`, whereas before it
    was treated as a raw pattern and converted to `/\/foo\//`.
    The reason for this change is that `/foo/` is a valid AWK expression
    and should be parsed as such.
  * Raw patterns may now contain hyphens, so e.g. `-p type-checking` now works.
    In theory this makes some valid AWK expressions (such as `NF-2`) not to be
    parsed as such, but they are either unlikely to be useful or could also be
    expressed in other ways (`NF!=2`).
  * Several new exports, mostly for testing/debugging patterns:
  * `TestPattern` now has a `Show` instance; `TestPattern` and `Expr` now have
    `Eq` instances.
  * The constructors of `TestPattern` are now exported.
  * `parseAwkExpr` is introduced and can be used in ghci to see how an AWK
* Wed Mar 14 2018 psimons@suse.com
- Update tasty to version 1.0.1.1.
  A more detailed change log is not available.
